lilypondparsertools.ReducedLyParser
===================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser

.. autoclass:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.debug
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.lexer
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.lexer_rules_object
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.logger
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.logger_path
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.output_path
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_apostrophes__APOSTROPHE
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_apostrophes__apostrophes__APOSTROPHE
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_beam__BRACKET_L
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_beam__BRACKET_R
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_body__chord_pitches
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_body__chord_pitches__positive_leaf_duration
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_pitches__CARAT_L__pitches__CARAT_R
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_commas__COMMA
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_commas__commas__commas
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__container
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__fixed_duration_container
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__leaf
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__tuplet
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component_list__EMPTY
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component_list__component_list__component
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_container__BRACE_L__component_list__BRACE_R
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_dots__EMPTY
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_dots__dots__DOT
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_error
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_fixed_duration_container__BRACE_L__FRACTION__BRACE_R
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf__leaf_body__post_events
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__chord_body
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__note_body
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__rest_body
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_measure__PIPE__FRACTION__component_list__PIPE
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_negative_leaf_duration__INTEGER_N__dots
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__pitch
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__pitch__positive_leaf_duration
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__positive_leaf_duration
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME__apostrophes
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME__commas
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitches__pitch
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitches__pitches__pitch
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_positive_leaf_duration__INTEGER_P__dots
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__beam
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__slur
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__tie
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_events__EMPTY
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_events__post_events__post_event
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__RESTNAME
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__RESTNAME__positive_leaf_duration
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__negative_leaf_duration
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_slur__PAREN_L
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_slur__PAREN_R
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__EMPTY
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__start__component
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__start__measure
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_tie__TILDE
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_tuplet__FRACTION__container
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.parser
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.parser_rules_object
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.pickle_path
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_FRACTION
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_INTEGER_N
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_INTEGER_P
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_PITCHNAME
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_error
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_newline
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.tokenize
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__call__
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__eq__
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__format__
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__hash__
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__ne__
      ~abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__repr__

Bases
-----

- :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.debug
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.lexer
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.lexer_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.logger
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.logger_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.output_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.parser
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.parser_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.pickle_path
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_apostrophes__APOSTROPHE
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_apostrophes__apostrophes__APOSTROPHE
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_beam__BRACKET_L
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_beam__BRACKET_R
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_body__chord_pitches
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_body__chord_pitches__positive_leaf_duration
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_chord_pitches__CARAT_L__pitches__CARAT_R
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_commas__COMMA
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_commas__commas__commas
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__container
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__fixed_duration_container
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__leaf
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component__tuplet
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component_list__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_component_list__component_list__component
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_container__BRACE_L__component_list__BRACE_R
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_dots__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_dots__dots__DOT
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_fixed_duration_container__BRACE_L__FRACTION__BRACE_R
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf__leaf_body__post_events
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__chord_body
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__note_body
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_leaf_body__rest_body
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_measure__PIPE__FRACTION__component_list__PIPE
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_negative_leaf_duration__INTEGER_N__dots
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__pitch
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__pitch__positive_leaf_duration
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_note_body__positive_leaf_duration
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME__apostrophes
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitch__PITCHNAME__commas
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitches__pitch
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_pitches__pitches__pitch
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_positive_leaf_duration__INTEGER_P__dots
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__beam
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__slur
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_event__tie
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_events__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_post_events__post_events__post_event
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__RESTNAME
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__RESTNAME__positive_leaf_duration
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_rest_body__negative_leaf_duration
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_slur__PAREN_L
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_slur__PAREN_R
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__EMPTY
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__start__component
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_start__start__measure
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_tie__TILDE
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.p_tuplet__FRACTION__container
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_FRACTION
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_INTEGER_N
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_INTEGER_P
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_PITCHNAME
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_error
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.t_newline
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.tokenize
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__call__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.ReducedLyParser.ReducedLyParser.__repr__
   :noindex:
